onBack property
void Function()?
onBack
final
The action to be performed before the back action.
Implementation
final void Function()? onBack;
The action to be performed before the back action.
final void Function()? onBack;